@@ -147,12 +147,12 @@ impl<P: Process> ProcessModule<P> {
         module: &Path,
     ) -> Result<Option<ProcessModule<P>>, IoOrNulError> {
         let module = U16CString::from_os_str(module.as_os_str())?;
-        Self::find_local_by_name_or_abs_path_wstr(&module)
+        Self::find_local_by_name_or_abs_path_wstr(&module).map_err(|e| e.into())
     }
 
     pub(crate) fn find_local_by_name_or_abs_path_wstr(
         module: &U16CStr,
-    ) -> Result<Option<ProcessModule<P>>, IoOrNulError> {
+    ) -> Result<Option<ProcessModule<P>>, io::Error> {
         let handle = unsafe { GetModuleHandleW(module.as_ptr()) };
         if handle.is_null() {
             let err = io::Error::last_os_error();
@@ -160,7 +160,7 @@ impl<P: Process> ProcessModule<P> {
                 return Ok(None);
             }
 
-            return Err(err.into());
+            return Err(err);
         }
 
         Ok(Some(unsafe { Self::new_local_unchecked(handle) }))
