@@ -1,6 +1,6 @@
 #![cfg(feature = "syringe")]
 
-use dll_syringe::{Syringe, process::Process, error::EjectError};
+use dll_syringe::{error::EjectError, process::Process, Syringe};
 
 #[allow(unused)]
 mod common;
@@ -31,4 +31,4 @@ syringe_test! {
         let err = result.unwrap_err();
         assert!(matches!(err, EjectError::ProcessInaccessible), "{:?}", err);
     }
-}
\ No newline at end of file
+}
